Struct power_flow_data::Bus30
source · pub struct Bus30 {
pub i: BusNum,
pub name: ArrayString<15>,
pub basekv: f64,
pub ide: i8,
pub gl: f64,
pub bl: f64,
pub area: AreaNum,
pub zone: ZoneNum,
pub vm: f64,
pub va: f64,
pub owner: OwnerNum,
}Expand description
Network bus data record (in PSSE v30 format).
Each bus data record includes not only data for the basic bus properties but also includes information on an optionally connected shunt admittance to ground. That admittance can represent a shunt capacitor or a shunt reactor (both with or without a real component) or a shunt resistor. It must not represent line connected admittance, loads, line charging or transformer magnetizing impedance, all of which are entered in other data categories.
Fields
i: BusNumBus number (1 to 999997).
name: ArrayString<15>Alphanumeric identifier assigned to bus “I”. The name may be up to twelve characters and must be enclosed in single quotes. NAME may contain any combination of blanks, uppercase letters, numbers and special characters, but the first character must not be a minus sign.
basekv: f64Bus base voltage; entered in kV.
ide: i8Bus type code:
- load bus or other bus without any generator boundary condition.
- generator or plant bus either regulating voltage or with a fixed reactive power (Mvar). A generator that reaches its reactive power limit will no longer control voltage but rather hold reactive power at its limit.
- swing bus or slack bus. It has no power or reactive limits and regulates voltage at a fixed reference angle.
- disconnected or isolated bus.
gl: f64Active component of shunt admittance to ground; entered in MW at one per unit voltage. GL should not include any resistive admittance load, which is entered as part of load data.
bl: f64Reactive component of shunt admittance to ground; entered in Mvar at one per unit voltage. BL should not include any reactive impedance load, which is entered as part of load data; line charging and line connected shunts, which are entered as part of non-transformer branch data; or transformer magnetizing admittance, which is entered as part of transformer data. BL is positive for a capacitor, and negative for a reactor or an inductive load.
area: AreaNumArea number. 1 through the maximum number of areas at the current size level.
zone: ZoneNumZone number. 1 through the maximum number of zones at the current size level. See Zone.
vm: f64Bus voltage magnitude; entered in pu.
va: f64Bus voltage phase angle; entered in degrees.
owner: OwnerNumOwner number. 1 through the maximum number of owners at the current size level. See Owner.