FACTSDevice

Struct FACTSDevice 

pub struct FACTSDevice {
Show 21 fields pub name: ArrayString<15>, pub i: BusNum, pub j: BusNum, pub mode: i8, pub pdes: f64, pub qdes: f64, pub vset: f64, pub shmx: f64, pub trmx: f64, pub vtmn: f64, pub vtmx: f64, pub vsmx: f64, pub imx: f64, pub linx: f64, pub rmpct: f64, pub owner: OwnerNum, pub set1: f64, pub set2: f64, pub vsref: i8, pub remot: BusNum, pub mname: ArrayString<15>,
}
Flexible AC Transmission System devices.

There is a multiplicity of Flexible AC Transmission System devices currently available comprising shunt devices, such as the Static Compensator (STATCOM), series devices such as the Static Synchronous Series Compensator (SSSC), combined devices such as the Unified Power Flow Controller (UPFC) and the Interline Power Flow Controllers (IPFC), of which the latter are parallel series devices.

Fields

name: ArrayString<15>

The non-blank alphanumeric identifier assigned to this FACTS device. Each FACTS device must have a unique name. name` may be up to twelve characters and may contain any combination of blanks, uppercase letters, numbers and special characters. name must be enclosed in single or double quotes if it contains any blanks or special characters. No default allowed.

i: BusNum

Sending end bus number, or extended bus name enclosed in single quotes. No default.

j: BusNum

Terminal end bus number, or extended bus name enclosed in single quotes. 0 for a STATCON. j = 0 by default.

mode: i8

Control mode:

  • 0 - out-of-service (i.e., series and shunt links open).
  • 1 - series and shunt links operating.
  • 2 - series link bypassed (i.e., like a zero impedance line) and shunt link operating as a STATCON.
  • 3 - series and shunt links operating with series link at constant series impedance.
  • 4 - series and shunt links operating with series link at constant series voltage.
  • 5 - master device of an IPFC with P and Q setpoints specified; FACTS device N+1 must be the slave device (i.e., its mode is 6 or 8) of this IPFC.
  • 6 - slave device of an IPFC with P and Q setpoints specified; FACTS device N-1 must be the master device (i.e., its mode is 5 or 7) of this IPFC. The Q setpoint is ignored as the master device dictates the active power exchanged between the two devices.
  • 7 - master device of an IPFC with constant series voltage setpoints specified; FACTS device N+1 must be the slave device (i.e., its mode is 6 or 8) of this IPFC.
  • 8 - slave device of an IPFC with constant series voltage setpoints specified; FACTS device N-1 must be the master device (i.e., its mode is 5 or 7) of this IPFC. The complex V_d + j V_q setpoint is modified during power flow solutions to reflect the active power exchange determined by the master device. If j is specified as 0, mode must be either 0 or 1. mode = 1 by default.
pdes: f64

Desired active power flow arriving at the terminal end bus; entered in MW. pdes = 0.0 by default.

qdes: f64

Desired reactive power flow arriving at the terminal end bus; entered in MVAR. qdes = 0.0 by default.

vset: f64

Voltage setpoint at the sending end bus; entered in pu. vset = 1.0 by default.

shmx: f64

Maximum shunt current at the sending end bus; entered in MVA at unity voltage. shmx = 9999.0 by default.

trmx: f64

Maximum bridge active power transfer; entered in MW. trmx = 9999.0 by default.

vtmn: f64

Minimum voltage at the terminal end bus; entered in pu. vtmn = 0.9 by default.

vtmx: f64

Maximum voltage at the terminal end bus; entered in pu. vtmx = 1.1 by default.

vsmx: f64

Maximum series voltage; entered in pu. vsmx = 1.0 by default.

imx: f64

Maximum series current, or zero for no series current limit; entered in MVA at unity voltage. imx = 0.0 by default.

linx: f64

Reactance of the dummy series element used during model solution; entered in pu. linx = 0.05 by default.

rmpct: f64

Percent of the total Mvar required to hold the voltage at bus i that are to be contributed by the shunt element of this FACTS device; rmpct must be positive. rmpct is needed only if there is more than one local or remote voltage controlling device (plant, switched shunt, FACTS device shunt element, or VSC dc line converter) controlling the voltage at bus i to a setpoint. rmpct = 100.0 by default.

owner: OwnerNum

Owner number (1 through the maximum number of owners at the current size level). owner = 1 by default.

set1: f64

If mode is 3, resistance and reactance respectively of the constant impedance, entered in pu; if mode is 4, the magnitude (in pu) and angle (in degrees) of the constant series voltage with respect to the quantity indicated by vsref; if mode is 7 or 8, the real (vd) and imaginary (vq) components (in pu) of the constant series voltage with respect to the quantity indicated by vsref; for other values of mode, set1 and set2 are read, but not saved or used during power flow solutions. set1 = 0.0 by default.

set2: f64

See set1. set2 = 0.0 by default.

vsref: i8

Series voltage reference code to indicate the series voltage reference of set1 and set2 when mode is 4, 7 or 8: 0 for sending end voltage, 1 for series current. vsref = 0 by default.

remot: BusNum

Bus number, or extended bus name enclosed in single quotes, of a remote Type 1 or 2 bus where voltage is to be regulated by the shunt element of this FACTS device to the value specified by vset. if bus remot is other than a type 1 or 2 bus, the shunt element regulates voltage at the sending end bus to the value specified by vset. remot is entered as zero if the shunt element is to regulate voltage at the sending end bus and must be zero if the sending end bus is a type 3 (swing) bus. remot = 0 by default.

mname: ArrayString<15>

The name of the FACTS device that is the IPFC master device when this FACTS device is the “slave” device of an IPFC (i.e., its mode is specified as 6 or 8). mname must be enclosed in single or double quotes if it contains any blanks or special characters. mname is blank by default.