Struct power_flow_data::Generator
source · pub struct Generator {Show 28 fields
pub i: BusNum,
pub id: ArrayString<3>,
pub pg: f64,
pub qg: f64,
pub qt: f64,
pub qb: f64,
pub vs: f64,
pub ireg: BusNum,
pub mbase: f64,
pub zr: f64,
pub zx: f64,
pub rt: f64,
pub xt: f64,
pub gtap: f64,
pub stat: bool,
pub rmpct: f64,
pub pt: f64,
pub pb: f64,
pub o1: OwnerNum,
pub f1: Option<f64>,
pub o2: Option<OwnerNum>,
pub f2: Option<f64>,
pub o3: Option<OwnerNum>,
pub f3: Option<f64>,
pub o4: Option<OwnerNum>,
pub f4: Option<f64>,
pub wmod: Option<i8>,
pub wpf: Option<f64>,
}Expand description
Each network bus to be represented as a generator or plant bus in PSS/E must be specified in a generator data record. In particular, each bus specified in the bus data input with a type code of two (2) or three (3) must have a generator data record entered for it.
Fields
i: BusNumBus number, or extended bus name enclosed in single quotes.
id: ArrayString<3>One- or two-character uppercase non blank alphanumeric machine identifier used to distinguish among multiple machines at bus “I”. It is recommended that, at buses for which a single machine is present, the machine be designated as having the machine identifier ’1’. ID = ’1’ by default.
pg: f64Generator active power output; entered in MW. PG = 0.0 by default.
qg: f64Generator reactive power output; entered in Mvar. QG needs to be entered only if the case, as read in, is to be treated as a solved case. QG = 0.0 by default.
qt: f64Maximum generator reactive power output; entered in Mvar. For fixed output generators (i.e., nonregulating), QT must be equal to the fixed Mvar output. QT = 9999.0 by default.
qb: f64Minimum generator reactive power output; entered in Mvar. For fixed output generators, QB must be equal to the fixed Mvar output. QB = -9999.0 by default.
vs: f64Regulated voltage setpoint; entered in pu. VS = 1.0 by default.
ireg: BusNumBus number, or extended bus name enclosed in single quotes, of a remote type 1 or 2 bus whose voltage is to be regulated by this plant to the value specified by VS. If bus IREG is other than a type 1 or 2 bus, bus “I” regulates its own voltage to the value specified by VS. IREG is entered as zero if the plant is to regulate its own voltage and must be zero for a type three (swing) bus. IREG = 0 by default.
mbase: f64Total MVA base of the units represented by this machine; entered in MVA. This quantity is not needed in normal power flow and equivalent onstruction work, but is required for switching studies, fault analysis, and dynamic simulation. MBASE = system base MVA by default.
zr: f64Complex machine impedance, ZSORCE; entered in pu on MBASE base. This data is not needed in normal power flow and equivalent construction work, but is required for switching studies, fault analysis, and dynamic simulation. For dynamic simulation, this impedance must be set equal to the unsaturated subtransient impedance for those generators to be modeled by subtransient level machine models, and to unsaturated transient impedance for those to be modeled by classical or transient level models. For short-circuit studies, the saturated subtransient or transient impedance should be used. ZR = 0.0 by default.
zx: f64See zr. ZX = 1.0 by default.
rt: f64Step-up transformer impedance, XTRAN; entered in pu on MBASE base. XTRAN should be entered as zero if the step-up transformer is explicitly modeled as a network branch and bus “I” is the terminal bus. RT+jXT = 0.0 by default.
xt: f64See rt. RT+jXT = 0.0 by default.
gtap: f64Step-up transformer off-nominal turns ratio; entered in pu. GTAP is used only if XTRAN is nonzero. GTAP = 1.0 by default.
stat: boolInitial machine status of one for in-service and zero for out-of-service. STAT = 1 by default.
rmpct: f64Percent of the total Mvar required to hold the voltage at the bus controlled by this bus “I” that are to be contributed by the generation at bus “I”; RMPCT must be positive. RMPCT is needed if IREG specifies a valid remote bus and there is more than one local or remote voltage controlling device (plant, switched shunt, FACTS device shunt element, or VSC DC line converter) controlling the voltage at bus IREG to a setpoint. RMPCT is needed also if bus “I” itself is being controlled locally or remotely by one or more other setpoint mode voltage controlling devices. RMPCT = 100.0 by default.
pt: f64Maximum generator active power output; entered in MW. PT = 9999.0 by default.
pb: f64Minimum generator active power output; entered in MW. PB = -9999.0 by default.
o1: OwnerNumOwner number (1 through the maximum number of owners at the current size level).
Each machine may have up to four owners. See Owner.
By default, o1 is the owner to which bus i is assigned and o2, o3, and o4 are
zero.
f1: Option<f64>Fraction of total ownership assigned to owner oi; each fi must be positive.
The fi values are normalized such that they sum to 1.0 before they are placed in the working case.
By default, each fi is 1.0.
o2: Option<OwnerNum>f2: Option<f64>o3: Option<OwnerNum>f3: Option<f64>o4: Option<OwnerNum>f4: Option<f64>wmod: Option<i8>Wind machine control mode; wmod is used to indicate whether a machine is a wind machine,
and, if it is, the type of reactive power limits to be imposed.
- 0 for a machine that is not a wind machine.
- 1 for a wind machine for which reactive power limits are specified by QT and QB.
- 2 for a wind machine for which reactive power limits are determined from the machine’s
active power output and
wpf; limits are of equal magnitude and opposite sign. - 3 for a wind machine with a fixed reactive power setting determined from the machine’s
active power output and
wpf; whenwpfis positive, the machine’s reactive power has the same sign as its active power; whenwpfis negative, the machine’s reactive power has the opposite sign of its active power.wmod= 0 by default.
wpf: Option<f64>Power factor used in calculating reactive power limits or output when wmod is 2 or 3.
wpf = 1.0 by default.