Load

Struct Load 

pub struct Load {
Show 14 fields pub i: BusNum, pub id: ArrayString<3>, pub status: Stat, pub area: AreaNum, pub zone: ZoneNum, pub pl: f64, pub ql: f64, pub ip: f64, pub iq: f64, pub yp: f64, pub yq: f64, pub owner: OwnerNum, pub scale: Option<bool>, pub intrpt: Option<bool>,
}
Each network bus at which a load is to be represented must be specified in at least one load data record. If multiple loads are to be represented at a bus, they must be individually identified in a load data record for the bus with a different load identifier. Each load at a bus can be a mixture of loads with different characteristics.

Fields

i: BusNum

Buses number, or extended buses name enclosed in single quotes.

id: ArrayString<3>

One- or two-character uppercase non-blank alphanumeric load identifier used to distinguish among multiple loads at bus “I”. It is recommended that, at buses for which a single load is present, the load be designated as having the load identifier ‘1’.

status: Stat

Initial load status of one for in-service and zero for out-of-service.

area: AreaNum

Area to which the load is assigned (1 through the maximum number of areas at the current size level).

zone: ZoneNum

Zone to which the load is assigned (1 through the maximum number of zones at the current size level). See Zone.

pl: f64

Active power component of constant MVA load; entered in MW.

ql: f64

Reactive power component of constant MVA load; entered in Mvar.

ip: f64

Active power component of constant current load; entered in MW at one per unit voltage.

iq: f64

Reactive power component of constant current load; entered in Mvar at one per unit voltage.

yp: f64

Active power component of constant admittance load; entered in MW at one per unit voltage.

yq: f64

Reactive power component of constant admittance load; entered in Mvar at one per unit voltage. YQ is a negative quantity for an inductive load and positive for a capacitive load.

owner: OwnerNum

Owner to which the load is assigned. 1 through the maximum number of owners at the current size level. See Owner.

scale: Option<bool>

Load scaling flag of one for a scalable load and zero for a fixed load. scale = 1 by default.

intrpt: Option<bool>

Interruptible load flag of one for an interruptible load for zero for a non interruptible load. intrpt=0 by default.