Network

Struct Network 

pub struct Network {
Show 19 fields pub version: i8, pub caseid: CaseID, pub buses: Vec<Bus>, pub loads: Vec<Load>, pub fixed_shunts: Vec<FixedShunt>, pub generators: Vec<Generator>, pub branches: Vec<Branch>, pub transformers: Vec<Transformer>, pub area_interchanges: Vec<AreaInterchange>, pub two_terminal_dc: Vec<TwoTerminalDCLine>, pub vsc_dc: Vec<VSCDCLine>, pub switched_shunts: Vec<SwitchedShunt>, pub impedance_corrections: Vec<ImpedanceCorrection>, pub multi_terminal_dc: Vec<MultiTerminalDCLine>, pub multi_section_lines: Vec<MultiSectionLineGroup>, pub zones: Vec<Zone>, pub area_transfers: Vec<InterAreaTransfer>, pub owners: Vec<Owner>, pub facts: Vec<FACTSDevice>,
}
Representation of a power network.

The PSS/E data format comprises 16 data categories of network and equipment elements, each of which requires a particular type of data.

Similarly, a Network stores the data from each category in its own dedicated structure.

Currently supported are:

  1. CaseID
  2. Bus
  3. Load
  4. FixedShunt
  5. Generator
  6. Branch
  7. Transformer
  8. AreaInterchange
  9. TwoTerminalDCLine
  10. VSCDCLine
  11. SwitchedShunt
  12. ImpedanceCorrection
  13. MultiTerminalDCLine
  14. MultiSectionLineGroup
  15. Zone
  16. InterAreaTransfer
  17. Owner
  18. FACTSDevice

Fields

version: i8

Version of the PSS/E data version given or detected when parsing.

caseid: CaseID

Case identification data.

buses: Vec<Bus>

Bus records.

loads: Vec<Load>

Load records.

fixed_shunts: Vec<FixedShunt>

Fixed Bus Shunt records.

generators: Vec<Generator>

Generator records.

branches: Vec<Branch>

Non-transformer Branch records.

transformers: Vec<Transformer>

Transformer records.

area_interchanges: Vec<AreaInterchange>

Area Interchange records.

two_terminal_dc: Vec<TwoTerminalDCLine>

Two-terminal DC Line records.

vsc_dc: Vec<VSCDCLine>

Voltage Source Converter DC Line records.

switched_shunts: Vec<SwitchedShunt>

Switched Shunt records.

impedance_corrections: Vec<ImpedanceCorrection>

Transformer impedance correction records.

multi_terminal_dc: Vec<MultiTerminalDCLine>

Multi-terminal DC Line records.

multi_section_lines: Vec<MultiSectionLineGroup>

Multi-section line group records.

zones: Vec<Zone>

Zone records.

area_transfers: Vec<InterAreaTransfer>

Inter-area transfer records.

owners: Vec<Owner>

Owner records.

facts: Vec<FACTSDevice>

FACTS device records.