Struct power_flow_data::Transformer
source · pub struct Transformer {Show 83 fields
pub i: BusNum,
pub j: BusNum,
pub k: BusNum,
pub ckt: ArrayString<3>,
pub cw: i8,
pub cz: i8,
pub cm: i8,
pub mag1: f64,
pub mag2: f64,
pub nmetr: i8,
pub name: ArrayString<15>,
pub stat: i8,
pub o1: OwnerNum,
pub f1: f64,
pub o2: Option<OwnerNum>,
pub f2: Option<f64>,
pub o3: Option<OwnerNum>,
pub f3: Option<f64>,
pub o4: Option<OwnerNum>,
pub f4: Option<f64>,
pub vecgrp: Option<ArrayString<15>>,
pub r1_2: f64,
pub x1_2: f64,
pub sbase1_2: f64,
pub r2_3: Option<f64>,
pub x2_3: Option<f64>,
pub sbase2_3: Option<f64>,
pub r3_1: Option<f64>,
pub x3_1: Option<f64>,
pub sbase3_1: Option<f64>,
pub vmstar: Option<f64>,
pub anstar: Option<f64>,
pub windv1: f64,
pub nomv1: f64,
pub ang1: f64,
pub rata1: f64,
pub ratb1: f64,
pub ratc1: f64,
pub cod1: i8,
pub cont1: BusNum,
pub rma1: f64,
pub rmi1: f64,
pub vma1: f64,
pub vmi1: f64,
pub ntp1: i16,
pub tab1: isize,
pub cr1: f64,
pub cx1: f64,
pub cnxa1: Option<f64>,
pub windv2: f64,
pub nomv2: f64,
pub ang2: Option<f64>,
pub rata2: Option<f64>,
pub ratb2: Option<f64>,
pub ratc2: Option<f64>,
pub cod2: Option<i8>,
pub cont2: Option<BusNum>,
pub rma2: Option<f64>,
pub rmi2: Option<f64>,
pub vma2: Option<f64>,
pub vmi2: Option<f64>,
pub ntp2: Option<i16>,
pub tab2: Option<isize>,
pub cr2: Option<f64>,
pub cx2: Option<f64>,
pub cnxa2: Option<f64>,
pub windv3: Option<f64>,
pub nomv3: Option<f64>,
pub ang3: Option<f64>,
pub rata3: Option<f64>,
pub ratb3: Option<f64>,
pub ratc3: Option<f64>,
pub cod3: Option<i8>,
pub cont3: Option<BusNum>,
pub rma3: Option<f64>,
pub rmi3: Option<f64>,
pub vma3: Option<f64>,
pub vmi3: Option<f64>,
pub ntp3: Option<i16>,
pub tab3: Option<isize>,
pub cr3: Option<f64>,
pub cx3: Option<f64>,
pub cnxa3: Option<f64>,
}Expand description
Each AC transformer to be represented in PSS/E is introduced through transformer data records that specify all the data required to model transformers in power flow calculations, with one exception.
That exception is a set of ancillary data, comprising transformer impedance correction records, which define the manner in which transformer impedance changes as off-nominal turns ratio or phase shift angle is adjusted. Those data records are described in Transformer Impedance Correction Records, ImpedanceCorrection.
Both two-winding and three-winding transformers are specified in the transformer data records. The data records for the two-winding transformer are common to the three-winding transformer; the data block for two-winding transformers is a subset of the data required for three-winding transformers.
Fields
i: BusNumThe bus number, or extended bus name enclosed in single quotes, of the bus to which the first winding is connected. The transformer’s magnetizing admittance is modeled on winding one. The first winding is the only winding of a two-winding transformer whose tap ratio or phase shift angle may be adjusted by the power flow solution activities; any winding(s) of a three-winding transformer may be adjusted. No default is allowed.
j: BusNumThe bus number, or extended bus name enclosed in single quotes, of the bus to which the second winding is connected. This winding may have a fixed, off-nominal tap ratio assigned to it. No default is allowed.
k: BusNumThe bus number, or extended bus name enclosed in single quotes, of the bus to which the third winding is connected. Zero is used to indicate that no third winding is present. Always equal to zero for a two-winding transformer.
ckt: ArrayString<3>One- or two-character uppercase nonblank alphanumeric transformer circuit identifier;
the first character of ckt must not be an ampersand (‘&’).
cw: i8The winding data I/O code which defines the units in which the turns ratios windv1 and
windv2 are specified (the units of rma1 and rmi1 are also governed by cw when
|cod1| is 1 or 2):
- 1 for off-nominal turns ratio in pu of winding bus base voltage;
- 2 for winding voltage in kV.
cw= 1 by default.
cz: i8The impedance data I/O code that defines the units in which the winding impedances
r1_2 and x1_2 are specified:
- 1 for resistance and reactance in pu on system base quantities;
- 2 for resistance and reactance in pu on a specified base MVA and winding bus base voltage;
- 3 for transformer load loss in watts and impedance magnitude in pu on a specified base MVA
and winding bus base voltage.
cz= 1 by default.
cm: i8The magnetizing admittance I/O code that defines the units in which mag1 and mag2 are specified:
- 1 for complex admittance in pu on system base quantities;
- 2 for no load loss in watts and exciting current in pu on winding one to two base MVA
and nominal voltage.
cm= 1 by default.
mag1: f64When cm is 1, mag1 is the magnetizing conductance in pu on system base quantities;
when cm is 2, mag1 is the no load loss in watts.
mag1 = 0.0 by default.
mag2: f64When cm is 1, mag2 is the magnetizing susceptance in pu on system base quantities;
when cm is 2, mag2 is the exciting current in pu on winding one to two base MVA (sbase1_2)
and nominal voltage (nomv1).
mag2 = 0.0 by default.
nmetr: i8The nonmetered end code of either:
- 1 (for the winding one bus), or
- 2 (for the winding two bus).
nmetr= 2 by default.
name: ArrayString<15>An alphanumeric identifier assigned to the transformer. The name may be up to twelve characters.
name may contain any combination of blanks, uppercase letters, numbers and special characters.
name is twelve blanks by default.
stat: i8The initial transformer status, where 1 designates in-service and 0 designates out-of-service.
stat = 1 by default.
o1: OwnerNumAn owner number; (1 through the maximum number of owners at the current size level). Each transformer may have up to four owners. See Owner. By default, O1 is the owner to which bus “I” is assigned
f1: f64The fraction of total ownership assigned to owner Oi; each Fi must be positive.
The Fi values are normalized such that they sum to 1.0 before they are placed in the working case.
By default, each fi is 1.0.
o2: Option<OwnerNum>f2: Option<f64>o3: Option<OwnerNum>f3: Option<f64>o4: Option<OwnerNum>f4: Option<f64>vecgrp: Option<ArrayString<15>>Alphanumeric identifier specifying vector group based on transformer winding connections and phase angles.
vecgrp value is used for information purpose only.
vecgrp is 12 blanks by default.
r1_2: f64The measured impedance of the transformer between the buses to which its first and second
windings are connected (see also x1_2).
- When
czis 1,r1_2is the resistance in pu on system base quantities; - when
czis 2,r1_2is the resistance in pu on winding one to two base MVA (sbase1_2) and winding one bus base voltage; - when
czis 3,r1_2is the load loss in watts.r1_2= 0.0 by default.
x1_2: f64The measured impedance of the transformer between the buses to which its first and second
windings are connected (see also r1_2).
- When
czis 1,x1_2is the reactance in pu on system base quantities; - when
czis 2,x1_2is the reactance in pu on winding one to two base MVA (sbase1_2) and winding one bus base voltage; - when
czis 3,x1_2is the impedance magnitude in pu on winding one to two base MVA (sbase1_2) and winding one bus base voltage.x1_2has no default.
sbase1_2: f64The winding one to two base MVA of the transformer.
sbase1_2 = sbase (the system base MVA) by default.
r2_3: Option<f64>The measured impedance of a three-winding transformer between the buses to which its
second and third windings are connected (see also x2_3).
- When
czis 1,r2_3is the resistance in pu on system base quantities; - when
czis 2,r2_3is the resistance in pu on winding two to three base MVA (sbase2_3) and winding two bus base voltage; - when
czis 3,r2_3is the load loss in wattsr2_3= 0.0 by default. Ignored for a two-winding transformer.
x2_3: Option<f64>The measured impedance of a three-winding transformer between the buses to which its
second and third windings are connected (see also x2_3).
- When
czis 1,x2_3is the reactance in pu on system base quantities; - when
czis 2,x2_3is the reactance in pu on winding one to two base MVA (sbas2_3) and winding one bus base voltage; - when
czis 3,x2_3is the impedance magnitude in pu on winding two to three base MVA (sbase2_3) and winding two bus base voltage.x2_3has no default. Ignored for a two-winding transformer.
sbase2_3: Option<f64>The winding two to three base MVA of a three-winding transformer; ignored for a two-winding
transformer.
sbase2_3 = sbase (the system base MVA) by default.
Ignored for a two-winding transformer.
r3_1: Option<f64>The measured impedance of a three-winding transformer between the buses to which its
third and first windings are connected (see also x3_1).
- When
czis 1,r3_1is the resistance in pu on system base quantities; - when
czis 2,r3_1is the resistance in pu on winding three to one base MVA (sbase3_1) and winding three bus base voltage; - when
czis 3,r3_1is the load loss in wattsr3_1= 0.0 by default. Ignored for a two-winding transformer.
x3_1: Option<f64>The measured impedance of a three-winding transformer between the buses to which its
third and first windings are connected (see also x3_1).
- When
czis 1,x3_1is the reactance in pu on system base quantities; - when
czis 2,x3_1is the reactance in pu on winding three to one base MVA (sbas3_1) and winding three bus base voltage; - when
czis 3,x3_1is the impedance magnitude in pu on winding three to one base MVA (sbase3_1) and winding three bus base voltage.x3_1has no default. Ignored for a two-winding transformer.
sbase3_1: Option<f64>The winding three to one base MVA of a three-winding transformer.
sbase3_1 = sbase (the system base MVA) by default.
Ignored for a two-winding transformer.
vmstar: Option<f64>The voltage magnitude at the hidden star point bus; entered in pu.
vmstar = 1.0 by default.
Ignored for a two-winding transformer.
anstar: Option<f64>The bus voltage phase angle at the hidden star point bus; entered in degrees.
anstar = 0.0 by default.
Ignored for a two-winding transformer.
windv1: f64When cw is 1, windv1 is the winding one off-nominal turns ratio in pu of winding one bus base voltage,
and windv1 = 1.0 by default.
When cw is 2, windv1 is the actual winding one voltage in kV,
and windv1 is equal to the base voltage of bus “I” by default.
nomv1: f64The nominal (rated) winding one voltage in kV, or zero to indicate that nominal winding
one voltage is to be taken as the base voltage of bus “I”.
nomv1 is used only in converting magnetizing data between per unit admittance values
and physical units when cm is 2.
nomv1 = 0.0 by default.
ang1: f64The winding one phase shift angle in degrees.
ang1 is positive for a positive phase shift from the winding one side to the winding two side (for a two-winding transformer).
ang1 must be greater than -180.0 and less than or equal to +180.0.
ang1 = 0.0 by default.
rata1: f64The first winding’s first rating entered in MVA (not current expressed in MVA).
ratb1: f64The first winding’s second rating entered in MVA (not current expressed in MVA).
ratc1: f64The first winding’s third rating entered in MVA (not current expressed in MVA).
cod1: i8The transformer control mode for automatic adjustments of the winding one tap or phase shift angle during power flow solutions:
- 0 for no control (fixed tap and phase shift);
- ±1 for voltage control;
- ±2 for reactive power flow control;
- ±3 for active power flow control;
- ±4 for control of a DC line quantity.
If the control mode is entered as a positive number, automatic adjustment of this transformer
winding is enabled when the corresponding adjustment is activated during power flow solutions;
a negative control mode suppresses the automatic adjustment of this transformer winding.
cod1= 0 by default.
cont1: BusNumThe bus number, or extended bus name enclosed in single quotes, of the bus whose voltage
is to be controlled by the transformer turns ratio adjustment option of the power flow
solution activities when cod1 is 1.
cont1 should be non-zero only for voltage controlling transformer windings.
cont1 may specify a bus other than “I”, “J”, or “K”; in this case, the sign of cont1
defines the location of the controlled bus relative to the transformer winding.
If cont1 is entered as a positive number, the ratio is adjusted as if bus cont1 is on the winding two side of the transformer;
if cont1 is entered as a negative number, the ratio is adjusted as if bus |cont1| is on the winding one side of the transformer.
cont1 = 0 by default.
rma1: f64rma1 is the upper limit (and rmi1 the lower limit) of either:
- Off-nominal turns ratio in pu of winding one bus base voltage when
|cod1|is 1 or 2 andcwis 1;rma1= 1.1 andrmi1= 0.9 by default. - Actual winding one voltage in kV when
|cod1|is 1 or 2 andcwis 2. No default is allowed. - Phase shift angl e in degrees when
|cod1|is 3. No default is allowed. - Not used when
|cod1|is 0 or 4;rma1= 1.1 andrmi1= 0.9 by default.
rmi1: f64The lower limit to rma1’s upper limit. See rma1 for details.
vma1: f64vma1 is the upper limit (and vmi1 the lower limit) of either:
- Voltage at the controlled bus (bus
|cont1|) in pu when|cod1|is 1.vma1= 1.1 andvmi1= 0.9 by default. - Reactive power flow into the transformer at the winding one bus end in Mvar when
|cod1|is 2. no default is allowed. - Active power flow into the transformer at the winding one bus end in MW when
|cod1|is 3. no default is allowed. - Not used when
|cod1|is 0 or 4;vma1= 1.1 andvmi1= 0.9 by default.
vmi1: f64The lower limit to vma1’s upper limit. See vma1 for details.
ntp1: i16The number of tap positions available; used when cod1 is 1 or 2.
ntp1 must be between 2 and 9999.
ntp1 = 33 by default.
tab1: isizeThe number of a transformer impedance correction record if this transformer winding’s
impedance is to be a function of either off-nominal turns ratio or phase shift angle,
or 0 if no transformer impedance correction is to be applied to this transformer winding.
See ImpedanceCorrection.
tab1 = 0 by default.
cr1: f64The load drop compensation impedance for voltage controlling transformers entered in pu
on system base quantities; used when cod1 is 1.
cr1 + jcx1 = 0.0 by default.
cx1: f64See cr1 for details.
cnxa1: Option<f64>Winding connection angle in degrees; used when cod1 is 5.
There are no restrictions on the value specified for cnxa1;
if it is outside of the range from -90.0 to +90.0, cnxa1 is normalized to within this range.
cnxa1 = 0.0 by default.
windv2: f64When cw is 1, windv2 is the winding two off-nominal turns ratio in pu of winding two bus base voltage,
and windv2 = 1.0 by default.
When cw is 2, windv2 is the actual winding two voltage in kV,
and windv2 is equal to the base voltage of bus j by default.
nomv2: f64The nominal (rated) winding two voltage in kV, or zero to indicate that nominal winding
two voltage is to be taken as the base voltage of bus j.
nomv2 is present for information purposes only; it is not used in any of the calculations
for modeling the transformer.
nomv2 = 0.0 by default.
ang2: Option<f64>The winding two phase shift angle in degrees.
ang2 is positive for a positive phase shift from the winding two side to the “T”
(or star) point bus.
ang2 must be greater than -180.0 and less than or equal to +180.0.
ang2 = 0.0 by default.
Ignored for a two-winding transformer.
rata2: Option<f64>The second winding’s first rating entered in MVA (not current expressed in MVA). Ignored for a two-winding transformer.
ratb2: Option<f64>The second winding’s second rating entered in MVA (not current expressed in MVA). Ignored for a two-winding transformer.
ratc2: Option<f64>The second winding’s third rating entered in MVA (not current expressed in MVA). Ignored for a two-winding transformer.
cod2: Option<i8>The transformer control mode for automatic adjustments of the winding two tap or phase shift angle during power flow solutions:
- 0 for no control (fixed tap and phase shift);
- ±1 for voltage control;
- ±2 for reactive power flow control;
- ±3 for active power flow control.
If the control mode is entered as a positive number, automatic adjustment of this transformer
winding is enabled when the corresponding adjustment is activated during power flow solutions;
a negative control mode suppresses the automatic adjustment of this transformer winding.
cod2= 0 by default. Ignored for a two-winding transformer.
cont2: Option<BusNum>The bus number, or extended bus name enclosed in single quotes, of the bus whose voltage
is to be controlled by the transformer turns ratio adjustment option of the power flow
solution activities when cod2 is 1.
cont2 should be nonzero only for voltage controlling transformer windings.
cont2 may specify a bus other than i, j, or k; in this case, the sign of
cont2 defines the location of the controlled bus relative to the transformer winding.
If cont2 is entered as a positive number, or a quoted extended bus name, the ratio is
adjusted as if bus cont2 is on the winding one or winding three side of the transformer;
if cont2 is entered as a negative number, or a quoted extended bus name with a minus sign
preceding the first character, the ratio is adjusted as if bus |cont2| is on the winding
two side of the transformer. cont2 = 0 by default.
Ignored for a two-winding transformer.
rma2: Option<f64>rma2 is the upper limit (and rmi2 the lower limit) of either:
- Off-nominal turns ratio in pu of winding two bus base voltage when
|cod2|is 1 or 2 andcwis 1;rma2= 1.1 andrmi2= 0.9 by default. - Actual winding one voltage in kV when
|cod2|is 1 or 2 andcwis 2. No default is allowed. - Phase shift angle in degrees when
|cod2|is 3. No default is allowed. - Not used when
|cod2|is 0;rma2= 1.1 andrmi2= 0.9 by default. Ignored for a two-winding transformer.
rmi2: Option<f64>The lower limit to rma2’s upper limit. See rma2 for details.
Ignored for a two-winding transformer.
vma2: Option<f64>vma2 is the upper limit (and vmi2 the lower limit) of either:
- Voltage at the controlled bus (bus
|cont2|) in pu when|cod2|is 1.vma2= 1.1 andvmi2= 0.9 by default. - Reactive power flow into the transformer at the winding two bus end in Mvar when
|cod2|is 2. No default is allowed. - Active power flow into the transformer at the winding two bus end in MW when
|cod2|is 3. No default is allowed. - Not used when
|cod2|is 0;vma2= 1.1 andvmi2= 0.9 by default. Ignored for a two-winding transformer.
vmi2: Option<f64>The lower limit to vma1’s upper limit. See vma1 for details.
Ignored for a two-winding transformer.
ntp2: Option<i16>The number of tap positions available; used when cod2 is 1 or 2.
ntp2 must be between 2 and 9999.
ntp2 = 33 by default.
Ignored for a two-winding transformer.
tab2: Option<isize>The number of a transformer impedance correction record if this transformer winding’s
impedance is to be a function of either off-nominal turns ratio or phase shift angle,
or 0 if no transformer impedance correction is to be applied to this transformer winding.
See ImpedanceCorrection.
tab2 = 0 by default.
Ignored for a two-winding transformer.
cr2: Option<f64>The load drop compensation impedance for voltage controlling transformers entered in pu
on system base quantities; used when cod2 is 1.
cr2 + jcx2 = 0.0 by default.
Ignored for a two-winding transformer.
cx2: Option<f64>See cr2 for details.
Ignored for a two-winding transformer.
cnxa2: Option<f64>Winding connection angle in degrees; used when cod2 is 5.
There are no restrictions on the value specified for cnxa2;
if it is outside of the range from -90.0 to +90.0, cnxa2 is normalized to within this range.
cnxa2 = 0.0 by default.
windv3: Option<f64>When cw is 1, windv3 is the winding three off-nominal turns ratio in pu of winding three bus base voltage,
and windv3 = 1.0 by default.
When cw is 2, windv3 is the actual winding three voltage in kV,
and windv3 is equal to the base voltage of bus k by default.
Ignored for a two-winding transformer.
nomv3: Option<f64>The nominal (rated) winding three voltage in kV, or zero to indicate that nominal winding
two voltage is to be taken as the base voltage of bus j.
nomv3 is present for information purposes only; it is not used in any of the calculations
for modeling the transformer.
nomv3 = 0.0 by default.
Ignored for a two-winding transformer.
ang3: Option<f64>The winding three phase shift angle in degrees.
ang3 is positive for a positive phase shift from the winding two side to the “T”
(or star) point bus.
ang3 must be greater than -180.0 and less than or equal to +180.0.
ang3 = 0.0 by default.
Ignored for a two-winding transformer.
rata3: Option<f64>The third winding’s first rating entered in MVA (not current expressed in MVA). Ignored for a two-winding transformer.
ratb3: Option<f64>The third winding’s second rating entered in MVA (not current expressed in MVA). Ignored for a two-winding transformer.
ratc3: Option<f64>The third winding’s third rating entered in MVA (not current expressed in MVA). Ignored for a two-winding transformer.
cod3: Option<i8>The transformer control mode for automatic adjustments of the winding three tap or phase shift angle during power flow solutions:
- 0 for no control (fixed tap and phase shift);
- ±1 for voltage control;
- ±2 for reactive power flow control;
- ±3 for active power flow control.
If the control mode is entered as a positive number, automatic adjustment of this transformer
winding is enabled when the corresponding adjustment is activated during power flow solutions;
a negative control mode suppresses the automatic adjustment of this transformer winding.
cod3= 0 by default. Ignored for a two-winding transformer.
cont3: Option<BusNum>The bus number, or extended bus name enclosed in single quotes, of the bus whose voltage
is to be controlled by the transformer turns ratio adjustment option of the power flow
solution activities when cod3 is 1.
cont3 should be nonzero only for voltage controlling transformer windings.
cont3 may specify a bus other than i, j, or k; in this case, the sign of
cont3 defines the location of the controlled bus relative to the transformer winding.
If cont3 is entered as a positive number, or a quoted extended bus name, the ratio is
adjusted as if bus cont3 is on the winding one or winding two side of the transformer;
if cont3 is entered as a negative number, or a quoted extended bus name with a minus sign
preceding the first character, the ratio is adjusted as if bus |cont3| is on the winding
three side of the transformer. cont3 = 0 by default.
Ignored for a two-winding transformer.
rma3: Option<f64>rma3 is the upper limit (and rmi3 the lower limit) of either:
- Off-nominal turns ratio in pu of winding three bus base voltage when
|cod3|is 1 or 2 andcwis 1;rma3= 1.1 andrmi3= 0.9 by default. - Actual winding one voltage in kV when
|cod3|is 1 or 2 andcwis 2. No default is allowed. - Phase shift angle in degrees when
|cod3|is 3. No default is allowed. - Not used when
|cod3|is 0;rma3= 1.1 andrmi3= 0.9 by default. Ignored for a two-winding transformer.
rmi3: Option<f64>The lower limit to rma3’s upper limit. See rma3 for details.
Ignored for a two-winding transformer.
vma3: Option<f64>vma3 is the upper limit (and vmi3 the lower limit) of either:
- Voltage at the controlled bus (bus
|cont3|) in pu when|cod3|is 1.vma3= 1.1 andvmi3= 0.9 by default. - Reactive power flow into the transformer at the winding three bus end in Mvar when
|cod3|is 2. No default is allowed. - Active power flow into the transformer at the winding two bus end in MW when
|cod3|is 3. No default is allowed. - Not used when
|cod3|is 0;vma3= 1.1 andvmi3= 0.9 by default. Ignored for a two-winding transformer.
vmi3: Option<f64>The lower limit to vma3’s upper limit. See vma3 for details.
Ignored for a two-winding transformer.
ntp3: Option<i16>The number of tap positions available; used when cod3 is 1 or 2.
ntp3 must be between 2 and 9999.
ntp3 = 33 by default.
Ignored for a two-winding transformer.
tab3: Option<isize>The number of a transformer impedance correction record if this transformer winding’s
impedance is to be a function of either off-nominal turns ratio or phase shift angle,
or 0 if no transformer impedance correction is to be applied to this transformer winding.
See ImpedanceCorrection.
tab3 = 0 by default.
Ignored for a two-winding transformer.
cr3: Option<f64>The load drop compensation impedance for voltage controlling transformers entered in pu
on system base quantities; used when cod3 is 1.
cr3 + jcx3 = 0.0 by default.
Ignored for a two-winding transformer.
cx3: Option<f64>See cr3 for details.
Ignored for a two-winding transformer.
cnxa3: Option<f64>Winding connection angle in degrees; used when cod3 is 5.
There are no restrictions on the value specified for cnxa3;
if it is outside of the range from -90.0 to +90.0, cnxa3 is normalized to within this range.
cnxa3 = 0.0 by default.